==> yawp-1.21.4-fabric-0.5.2-beta1-sources.jar: de/z0rdak/yawp/mixin/flag/player/ThrownEnderPearlMixin.java <==
package de.z0rdak.yawp.mixin.flag.player;

import de.z0rdak.yawp.api.events.region.FlagCheckEvent;
import de.z0rdak.yawp.platform.Services;
import net.minecraft.class_1297;
import net.minecraft.class_1657;
import net.minecraft.class_1684;
import net.minecraft.class_2338;
import net.minecraft.class_239;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;

import static de.z0rdak.yawp.core.flag.RegionFlag.USE_ENDERPEARL_FROM_REGION;
import static de.z0rdak.yawp.core.flag.RegionFlag.USE_ENDERPEARL_TO_REGION;
import static de.z0rdak.yawp.handler.HandlerUtil.*;
import static de.z0rdak.yawp.api.MessageSender.sendFlagMsg;

@Mixin(class_1684.class)
public abstract class ThrownEnderPearlMixin {

    @Inject(method = "onHit", at = @At(value = "INVOKE", target = "Lnet/minecraft/util/RandomSource;nextFloat()F"), cancellable = true, allow = 1)
    public void onThrowPearlIntoRegion(class_239 hitResult, CallbackInfo ci) {
        class_1684 pearl = (class_1684) (Object) this;
        if (isServerSide(pearl.method_37908())) {
            class_1297 owner = pearl.method_24921();
            if (owner instanceof class_1657 player) {
                class_2338 targetBlockPos = new class_2338(pearl.method_31477(), pearl.method_31478(), pearl.method_31479());
                FlagCheckEvent checkEvent = new FlagCheckEvent(targetBlockPos, USE_ENDERPEARL_TO_REGION, getDimKey(player), player);
                if (Services.EVENT.post(checkEvent))
                    return;
                processCheck(checkEvent, deny -> {
                    sendFlagMsg(deny);
                    ci.cancel();
                    pearl.method_5650(class_1297.class_5529.field_26999);
                });
            }
        }
    }

    @Inject(method = "onHit", at = @At(value = "INVOKE", target = "Lnet/minecraft/util/RandomSource;nextFloat()F"), cancellable = true, allow = 1)
    public void onThrowPearlOutOfRegion(class_239 hitResult, CallbackInfo ci) {
        class_1684 pearl = (class_1684) (Object) this;
        if (isServerSide(pearl.method_37908())) {
            class_1297 owner = pearl.method_24921();
            if (owner instanceof class_1657 player) {
                FlagCheckEvent checkEvent = new FlagCheckEvent(player.method_24515(), USE_ENDERPEARL_FROM_REGION, getDimKey(player), player);
                if (Services.EVENT.post(checkEvent))
                    return;
                processCheck(checkEvent, deny -> {
                    sendFlagMsg(deny);
                    ci.cancel();
                    pearl.method_5650(class_1297.class_5529.field_26999);
                });
            }
        }
    }
}

==> yawp-1.21.5-fabric-0.5.3-beta1-sources.jar: de/z0rdak/yawp/mixin/flag/player/ThrownEnderPearlMixin.java <==
package de.z0rdak.yawp.mixin.flag.player;

import de.z0rdak.yawp.api.FlagEvaluator;
import de.z0rdak.yawp.api.events.region.FlagCheckEvent;
import de.z0rdak.yawp.platform.Services;
import net.minecraft.class_1297;
import net.minecraft.class_1657;
import net.minecraft.class_1684;
import net.minecraft.class_2338;
import net.minecraft.class_239;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;

import static de.z0rdak.yawp.core.flag.RegionFlag.USE_ENDERPEARL_FROM_REGION;
import static de.z0rdak.yawp.core.flag.RegionFlag.USE_ENDERPEARL_TO_REGION;
import static de.z0rdak.yawp.handler.HandlerUtil.*;
import static de.z0rdak.yawp.api.MessageSender.sendFlagMsg;

@Mixin(class_1684.class)
public abstract class ThrownEnderPearlMixin {

    @Inject(method = "onHit", at = @At(value = "INVOKE", target = "Lnet/minecraft/util/RandomSource;nextFloat()F"), cancellable = true, allow = 1)
    public void onThrowPearlIntoRegion(class_239 hitResult, CallbackInfo ci) {
        class_1684 pearl = (class_1684) (Object) this;
        if (isServerSide(pearl.method_37908())) {
            class_1297 owner = pearl.method_24921();
            if (owner instanceof class_1657 player) {
                class_2338 targetBlockPos = new class_2338(pearl.method_31477(), pearl.method_31478(), pearl.method_31479());
                FlagCheckEvent checkEvent = new FlagCheckEvent(targetBlockPos, USE_ENDERPEARL_TO_REGION, getDimKey(player), player);
                if (Services.EVENT.post(checkEvent))
                    return;
                FlagEvaluator.processCheck(checkEvent, deny -> {
                    sendFlagMsg(deny);
                    ci.cancel();
                    pearl.method_5650(class_1297.class_5529.field_26999);
                });
            }
        }
    }

    @Inject(method = "onHit", at = @At(value = "INVOKE", target = "Lnet/minecraft/util/RandomSource;nextFloat()F"), cancellable = true, allow = 1)
    public void onThrowPearlOutOfRegion(class_239 hitResult, CallbackInfo ci) {
        class_1684 pearl = (class_1684) (Object) this;
        if (isServerSide(pearl.method_37908())) {
            class_1297 owner = pearl.method_24921();
            if (owner instanceof class_1657 player) {
                FlagCheckEvent checkEvent = new FlagCheckEvent(player.method_24515(), USE_ENDERPEARL_FROM_REGION, getDimKey(player), player);
                if (Services.EVENT.post(checkEvent))
                    return;
                FlagEvaluator.processCheck(checkEvent, deny -> {
                    sendFlagMsg(deny);
                    ci.cancel();
                    pearl.method_5650(class_1297.class_5529.field_26999);
                });
            }
        }
    }
}
